@@ -130,7 +130,56 @@ NULL
 #' @references Fry, E. B. (1997). Fry 1000 instant words. Lincolnwood, IL: 
 #' Contemporary Books.
 NULL
+
+#' Fry's 1000 Most Commonly Used English Words
+#' 
+#' A stopword list containing a character vector of stopwords. 
+#' 
+#' @details Fry's 1000 Word List makes up 90\% of all printed text.
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name Fry_1000 
+#' @usage data(Fry_1000) 
+#' @format A vector with 1000 elements 
+#' @references Fry, E. B. (1997). Fry 1000 instant words. Lincolnwood, IL: 
+#' Contemporary Books.
+NULL
  
+#' Leveled Dolch List of 220 Common Words
+#' 
+#' Edward William Dolch's list of 220 Most Commonly Used Words by reading level.
+#' 
+#' @details Dolch's Word List made up 50-75\% of all printed text in 1936.
+#' \itemize{ 
+#'   \item Word. The word
+#'   \item Level. The reading level of the word
+#' } 
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name Leveled_Dolch 
+#' @usage data(Leveled_Dolch) 
+#' @format A data frame with 220 rows and 2 variables 
+#' @references Dolch, E. W. (1936). A basic sight vocabulary. Elementary School
+#' Journal, 36, 456-460.
+NULL
+ 
+#' Dolch List of 220 Common Words
+#' 
+#' Edward William Dolch's list of 220 Most Commonly Used Words.
+#' 
+#' @details Dolch's Word List made up 50-75\% of all printed text in 1936.
+#' 
+#' @docType data 
+#' @keywords datasets 
+#' @name Dolch 
+#' @usage data(Dolch) 
+#' @format A vector with 220 elements 
+#' @references Dolch, E. W. (1936). A basic sight vocabulary. Elementary School
+#' Journal, 36, 456-460.
+NULL
+
 #' Small Abbreviations Data Set
 #' 
 #' A dataset containing abbreviations and their qdap friendly form.
